==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebComponentBoolValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentBoolValueChangedEventArgsDescription } from "./WebComponentBoolValueChangedEventArgsDescription";
/**
 * @hidden
 */
export let WebComponentBoolValueChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebComponentBoolValueChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebComponentBoolValueChangedEventArgsDescriptionMetadata.a == null) {
                WebComponentBoolValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebComponentBoolValueChangedEventArgsDescriptionMetadata.c(WebComponentBoolValueChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebComponentBoolValueChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebComponentBoolValueChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ComponentBoolValueChangedEventArgs");
            a.item("Detail", "Boolean");
        }
        static d(a) {
            WebComponentBoolValueChangedEventArgsDescriptionMetadata.b(a);
            a.aa("WebComponentBoolValueChangedEventArgs", () => new WebComponentBoolValueChangedEventArgsDescription());
            a.z("WebComponentBoolValueChangedEventArgs", WebComponentBoolValueChangedEventArgsDescriptionMetadata.a);
        }
    }
    WebComponentBoolValueChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebComponentBoolValueChangedEventArgsDescriptionMetadata, 'WebComponentBoolValueChangedEventArgsDescriptionMetadata');
    WebComponentBoolValueChangedEventArgsDescriptionMetadata.a = null;
    return WebComponentBoolValueChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebComponentBoolValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentBoolValueChangedEventArgsDescription } from "./WebComponentBoolValueChangedEventArgsDescription";
/**
 * @hidden
 */
export let WebComponentBoolValueChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebComponentBoolValueChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebComponentBoolValueChangedEventArgsDescriptionMetadata.a == null) {
                WebComponentBoolValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebComponentBoolValueChangedEventArgsDescriptionMetadata.c(WebComponentBoolValueChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebComponentBoolValueChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebComponentBoolValueChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ComponentBoolValueChangedEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Detail", "Boolean");
        }
        static d(a) {
            WebComponentBoolValueChangedEventArgsDescriptionMetadata.b(a);
            a.ac("WebComponentBoolValueChangedEventArgs", () => new WebComponentBoolValueChangedEventArgsDescription());
            a.ab("WebComponentBoolValueChangedEventArgs", WebComponentBoolValueChangedEventArgsDescriptionMetadata.a);
        }
    }
    WebComponentBoolValueChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebComponentBoolValueChangedEventArgsDescriptionMetadata, 'WebComponentBoolValueChangedEventArgsDescriptionMetadata');
    WebComponentBoolValueChangedEventArgsDescriptionMetadata.a = null;
    return WebComponentBoolValueChangedEventArgsDescriptionMetadata;
})();
